# SceneBox

SceneBox, is data platform that simplifies the collection, discovery, and management of large volumes of perception data
such as high-resolution images, LiDAR, and video. As a complete AI management platform, SceneBox provides API
integration with labeling providers and ML model lifecycle and deployment management.
